"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.history = exports.findAllWithSkip = exports.findAll = exports.findOne = void 0;
var KMP_1 = require("./KMP-utils/KMP");
var history = require("./history/history");
exports.history = history;
var findOne = function (text, word, options) {
    if (options === void 0) { options = {}; }
    if (!text || !word) {
        return -1;
    }
    if (!options.caseSensative) {
        text = text.toLowerCase();
        word = word.toLowerCase();
    }
    var result = KMP_1.evalKMPPrefix(word);
    var maxLength = 0;
    for (var i = 0; i < text.length; i++) {
        while (maxLength > 0 && text[i] !== word[maxLength]) {
            maxLength = result[maxLength - 1];
        }
        if (text[i] === word[maxLength]) {
            maxLength++;
        }
        if (maxLength === word.length) {
            return i + 1 - word.length;
        }
    }
    return -1;
};
exports.findOne = findOne;
var findAll = function (text, word, options) {
    if (options === void 0) { options = {}; }
    if (!text) {
        return [];
    }
    if (!word) {
        return [];
    }
    if (!options.caseSensative) {
        text = text.toLowerCase();
        word = word.toLowerCase();
    }
    var result = KMP_1.evalKMPPrefix(word);
    var allPositions = [];
    var maxLength = 0;
    for (var i = 0; i < text.length; i++) {
        while (maxLength > 0 && text[i] !== word[maxLength]) {
            maxLength = result[maxLength - 1];
        }
        if (text[i] === word[maxLength]) {
            maxLength++;
        }
        if (maxLength === word.length) {
            allPositions.push(i + 1 - word.length);
        }
    }
    if (allPositions.length) {
        return allPositions;
    }
    return [];
};
exports.findAll = findAll;
var findAllWithSkip = function (text, word, options) {
    if (options === void 0) { options = {}; }
    var results = exports.findAll(text, word, options);
    var skipXFirstResults = options.skipXFirstResults, skipXLastResults = options.skipXLastResults;
    if (skipXFirstResults && skipXFirstResults > 0) {
        return results.slice(skipXFirstResults);
    }
    if (skipXLastResults && skipXLastResults < 0) {
        return results.slice(0, skipXLastResults);
    }
    return results;
};
exports.findAllWithSkip = findAllWithSkip;
